%bcond_with bootstrap

Summary:        Fast Scanner Generator
Name:           jflex
Version:        1.7.0
Release:        %mkrel 12
Group:          Development/Java
License:        BSD
URL:            http://jflex.de/
BuildArch:      noarch

# ./create-tarball.sh %%{version}
Source0:        %{name}-%{version}-clean.tar.gz
Source4:        %{name}.1
Source5:        create-tarball.sh

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(java_cup:java_cup)
BuildRequires:  mvn(junit:junit)
BuildRequires:  maven-surefire-provider-junit
BuildRequires:  mvn(org.apache.ant:ant)
%endif

%if %{without bootstrap}
BuildRequires:  jflex
%endif

# Explicit javapackages-tools requires since scripts use
# /usr/share/java-utils/java-functions
Requires:       javapackages-tools

%description
JFlex is a lexical analyzer generator (also known as scanner
generator) for Java, written in Java.  It is also a rewrite of the
very useful tool JLex which was developed by Elliot Berk at Princeton
University.  As Vern Paxson states for his C/C++ tool flex: They do
not share any code though.  JFlex is designed to work together with
the LALR parser generator CUP by Scott Hudson, and the Java
modification of Berkeley Yacc BYacc/J by Bob Jamison.  It can also be
used together with other parser generators like ANTLR or as a
standalone tool.

%package javadoc
Summary:        API documentation for %{name}

%description javadoc
This package provides %{summary}.

%prep
%setup -q
%mvn_file : %{name}
%pom_add_dep java_cup:java_cup

%pom_remove_plugin :jflex-maven-plugin
%pom_remove_plugin :cup-maven-plugin
%pom_remove_plugin :maven-shade-plugin
%pom_remove_dep :cup_runtime

# Tests fail with 320k stacks (default on i686), so lets increase
# stack to 16M to avoid stack overflows.  See rhbz#1119308
%pom_xpath_inject "pom:plugin[pom:artifactId='maven-surefire-plugin']/pom:configuration" "<argLine>-Xss16384k</argLine>"

%pom_xpath_remove "pom:plugin[pom:artifactId='maven-site-plugin']" parent.xml
%pom_xpath_remove "pom:plugin[pom:artifactId='fmt-maven-plugin']" parent.xml
%pom_xpath_remove "pom:plugin[pom:artifactId='cup-maven-plugin']" parent.xml
%pom_xpath_remove "pom:plugin[pom:artifactId='maven-shade-plugin']" parent.xml

%pom_xpath_remove "pom:dependency[pom:artifactId='plexus-compiler-javac-errorprone']" parent.xml
%pom_xpath_remove "pom:dependency[pom:artifactId='error_prone_core']" parent.xml
%pom_xpath_remove "pom:compilerId" parent.xml
%pom_xpath_remove "pom:compilerArgs" parent.xml

sed -i /%%inputstreamctor/d src/main/jflex/LexScan.flex

%build
%{?jpb_env}
cup -parser LexParse -interface -destdir src/main/java src/main/cup/LexParse.cup
jflex -d src/main/java/jflex --skel src/main/jflex/skeleton.nested src/main/jflex/LexScan.flex
%mvn_build

%install
%mvn_install

# wrapper script for direct execution
%jpackage_script jflex.Main "" "" jflex:java_cup jflex true

# manpage
install -d -m 755 %{buildroot}%{_mandir}/man1
install -p -m 644 %{SOURCE4} %{buildroot}%{_mandir}/man1

%files -f .mfiles
%doc doc
%doc COPYRIGHT
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*

%files javadoc
%doc COPYRIGHT
%doc %{_javadocdir}/%{name}



%changelog
* Mon Jul 25 2022 neoclust <neoclust> 1.7.0-12.mga9
+ Revision: 1871212
- Disable bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 1.7.0-11.mga9
+ Revision: 1870582
- Adapt BR to new javapackages-bootstrap
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sun Feb 16 2020 umeabot <umeabot> 1.7.0-2.mga8
+ Revision: 1536133
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 1.7.0-1.mga8
+ Revision: 1453309
- Update to version 1.7.0

* Tue Sep 18 2018 umeabot <umeabot> 1.6.1-7.mga7
+ Revision: 1263080
- Mageia 7 Mass Rebuild

* Wed May 17 2017 neoclust <neoclust> 1.6.1-6.mga6
+ Revision: 1102794
- Fix build
- Second rebuild of the java stack

* Mon Feb 29 2016 neoclust <neoclust> 1.6.1-4.mga6
+ Revision: 980709
- First rebuild of the java stack
- sync package jflex with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
+ zezinho <zezinho>
- new version

* Fri Jan 30 2015 daviddavid <daviddavid> 0:1.4.3-10.mga5
+ Revision: 812731
- use .mfiles generated during build
- update Requires
- remove no longer needed workaround for javadoc generation

* Wed Oct 15 2014 umeabot <umeabot> 0:1.4.3-9.mga5
+ Revision: 742184
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:1.4.3-8.mga5
+ Revision: 680792
- Mageia 5 Mass Rebuild

* Tue Aug 19 2014 luigiwalser <luigiwalser> 0:1.4.3-7.mga5
+ Revision: 665515
- obsolete jlex

* Fri Oct 18 2013 umeabot <umeabot> 0:1.4.3-6.mga4
+ Revision: 522283
- Mageia 4 Mass Rebuild

* Mon Feb 18 2013 dmorgan <dmorgan> 0:1.4.3-5.mga3
+ Revision: 399126
- Clean spec file
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 03 2011 dmorgan <dmorgan> 0:1.4.3-4.mga2
+ Revision: 162423
- Fix BuildRequires
+ gil <gil>
- added new script
- edit spec file
- used ju fedora new macro

* Mon Jan 17 2011 dmorgan <dmorgan> 0:1.4.3-1.mga1
+ Revision: 21638
- Add missing patch
- Add missing file
- New version
  Sync with fedora

* Mon Jan 17 2011 dmorgan <dmorgan> 0:1.4.1-15.mga1
+ Revision: 21626
- Enable bootstrap
- imported package jflex


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.4.1-15mdv2011.0
+ Revision: 606081
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 0:1.4.1-14mdv2010.1
+ Revision: 523084
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0:1.4.1-13mdv2010.0
+ Revision: 425460
- rebuild

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 0:1.4.1-12mdv2009.0
+ Revision: 221710
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:1.4.1-11mdv2008.1
+ Revision: 120941
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:1.4.1-10mdv2008.0
+ Revision: 87433
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Sat Sep 08 2007 Pascal Terjan <pterjan@mandriva.org> 0:1.4.1-9mdv2008.0
+ Revision: 82536
- update to new version


* Wed Nov 08 2006 David Walluck <walluck@mandriva.org>
+ 2006-11-08 04:53:36 (78038)
- BuildRequires: jflex for non-bootstrap
- disable bootstrap

* Tue Nov 07 2006 David Walluck <walluck@mandriva.org> 1.4.1-6mdv2007.1
+ 2006-11-07 12:12:56 (77050)
- fix some (Build)Requires
- enable bootstrap
- Import jflex

* Sun Sep 10 2006 David Walluck <walluck@mandriva.org> 0:1.4.1-4mdv2007.0
- fix build by removing included java_cup sources

* Sun Sep 10 2006 David Walluck <walluck@mandriva.org> 0:1.4.1-3mdv2007.0
- don't clean generated files before build (fails)
- add byaccj url fix from Debian
- remove jflex dir from $RPM_BUILD_DIR

* Sun Sep 10 2006 David Walluck <walluck@mandriva.org> 0:1.4.1-2mdv2007.0
- clean build environment

* Sat Sep 09 2006 David Walluck <walluck@mandriva.org> 0:1.4.1-1mdv2007.0
- release

